\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{bible}[2013/07/14 A LaTeX Class for typestting Bibles]
\RequirePackage{xparse}
\RequirePackage{color}

\DeclareOption*{\PassOptionsToClass{\CurrentOption}{memoir}}
\ProcessOptions\relax

\LoadClass{memoir}

\RequirePackage{geometry}
\geometry{top=2cm,bottom=3cm,inner=2.5cm,outer=1cm}

\let\footruleskip\relax
\RequirePackage{fancyhdr}
\fancyhead[LE,RO]{\@ifundefined{@currbook}{}{\@currbook}}

\ExplSyntaxOn
\RequirePackage{xspace}

\newcounter{bookchapter}

\setcounter{book}{0}
\bool_new:c{is_first_verse}
\bool_new:c{is_first_chap}

\DeclareDocumentCommand{\bookchapter}{o}{
  % #1 Title

  % Step the chapter counter
  \refstepcounter{bookchapter}

  % Seperate chapters with a bit of space
  \vspace{2ex plus .2ex minus .2ex}

  % Fancy chapter numbers
  \bool_if:cTF{is_first_chap}
    {\bool_set_false:c{is_first_chap}}
       {\adjustbox{scale={1.5}{2}}{\arabic{bookchapter}}}

  % If we have a chapter title, typeset it centered on the first line
  \IfValueTF{#1}
    {\centerline{\bfseries#1}}{}

  % Reset the verse counter

  \setcounter{verse}{0}

  % Set prohibit typesetting the index of the first verse
  \bool_set_true:c{is_first_verse}
}

\DeclareDocumentCommand{\verse}{}{
  % Step the verse counter
  \refstepcounter{verse}

  % If this is the first verse, don't typeset its little index
  \bool_if:cTF{is_first_verse}
    {\bool_set_false:c{is_first_verse}}
    {\textsuperscript{\arabic{verse}}}
    \noindent
  }

\RequirePackage{xstring}
\newcommand{\testbook}[1]{\def\inputbook@only{#1}}
\newif\iftypeset
\typesettrue
\newcommand{\inputbook}[1]{
  \iftypeset
  \begingroup
    \cs_if_exist:NTF{\inputbook@only}
      {\IfStrEq{#1}{\inputbook@only}{\input{\bibleversion/#1}\clearpage}}
      {\input{\bibleversion/#1}\clearpage}
  \endgroup
  \fi
}

\ExplSyntaxOff

\newcommand{\SetVersion}[1]{\def\bibleversion{#1}}

% Local Variables:
% mode: latex
% TeX-master: "bible.tex"
% TeX-engine: default
% TeX-PDF-mode: t
% End:
